@@ -99,7 +99,7 @@ initialize_contents (void)
   strcat (tempFileName, "lbx_body.temp");
   if (!(tempFile = fopen (tempFileName, "w")))
     {
-      logMessage (LOG_ERROR, "Can't open temporary file.\n");
+      logMessage (LOU_LOG_ERROR, "Can't open temporary file.\n");
       return 0;
     }
   ud->outFile = tempFile;
@@ -108,6 +108,8 @@ initialize_contents (void)
     ud->braille_page_number = ud->beginning_braille_page_number;
   else
     ud->braille_page_number = 1;
+  if (ud->has_pagebreak)
+    ud->page_number = 1;
   return 1;
 }
 
@@ -282,7 +284,7 @@ make_contents (void)
 
   if (!(tempFile = fopen (tempFileName, "r")))
     {
-      logMessage (LOG_ERROR, "Can't open temporary file.\n");
+      logMessage (LOU_LOG_ERROR, "Can't open temporary file.\n");
       return 0;
     }
   do
